@@ -45,6 +45,10 @@ import jenkins_jobs.modules.base
 ZUUL_PARAMETERS = [
     {'string':
          {'description': 'Zuul provided key to link builds with Gerrit events',
+          'name': 'ZUUL_UUID'}},
+    {'string':
+         {'description': 'Zuul provided key to link builds with Gerrit'
+             ' events (deprecated use ZUUL_UUID instead)',
           'name': 'UUID'}},
     {'string':
          {'description': 'Zuul pipeline triggering this job',
@@ -70,6 +74,9 @@ ZUUL_PARAMETERS = [
     {'string':
          {'description': 'Reference for the merged commit(s) to use',
           'name': 'ZUUL_REF'}},
+    {'string':
+         {'description': 'The commit SHA1 at the head of ZUUL_REF',
+          'name': 'ZUUL_COMMIT'}},
     {'string':
          {'description': 'List of included changes',
           'name': 'ZUUL_CHANGE_IDS'}},
@@ -84,6 +91,10 @@ ZUUL_PARAMETERS = [
 ZUUL_POST_PARAMETERS = [
     {'string':
          {'description': 'Zuul provided key to link builds with Gerrit events',
+          'name': 'ZUUL_UUID'}},
+    {'string':
+         {'description': 'Zuul provided key to link builds with Gerrit'
+            ' events (deprecated use ZUUL_UUID instead)',
           'name': 'UUID'}},
     {'string':
          {'description': 'Zuul pipeline triggering this job',
